@@ -91,22 +91,29 @@ class Plugin(plugin.PluginBase):
             if extensionsDir is not None and os.path.exists(extensionsDir):
                 shutil.rmtree(extensionsDir)
 
-    def sequenceLogin(self, extensionsDir):
-        user = self.dialog.queryString(
-            name='OVAAALDAP_LDAP_TOOL_SEQUENCE_LOGIN_USER',
-            note=_(
-                'Enter user name: '
-            ),
-            prompt=True,
-        )
-        password = self.dialog.queryString(
-            name='OVAAALDAP_LDAP_TOOL_SEQUENCE_LOGIN_PASSWORD',
-            note=_(
-                'Enter user password: '
-            ),
-            prompt=True,
-            hidden=True
+    def sequenceLogin(self, extensionsDir, user=None, password=None):
+        self.dialog.note(
+            text=(
+                _('Please provide credentials to test login flow:')
+            )
         )
+        if user is None:
+            user = self.dialog.queryString(
+                name='OVAAALDAP_LDAP_TOOL_SEQUENCE_LOGIN_USER',
+                note=_(
+                    'Enter user name: '
+                ),
+                prompt=True,
+            )
+        if password is None:
+            password = self.dialog.queryString(
+                name='OVAAALDAP_LDAP_TOOL_SEQUENCE_LOGIN_PASSWORD',
+                note=_(
+                    'Enter user password: '
+                ),
+                prompt=True,
+                hidden=True
+            )
         self.environment[
             otopicons.CoreEnv.LOG_FILTER
         ].append(password)
@@ -161,8 +168,14 @@ class Plugin(plugin.PluginBase):
                     )
                 )
             )
+        return rc == 0
 
     def sequenceSearch(self, extensionsDir):
+        self.dialog.note(
+            text=(
+                _('Please provide parameters for Search sequence:')
+            )
+        )
         entity = self.dialog.queryString(
             name='OVAAALDAP_LDAP_TOOL_SEQUENCE_SEARCH_ENTITY',
             note=_(
@@ -196,9 +209,12 @@ class Plugin(plugin.PluginBase):
                 ),
                 '--extensions-dir=%s/extensions.d' % extensionsDir,
                 'aaa', 'search',
-                '--extension-name=%s-authz' % self.environment[
-                    constants.LDAPEnv.AAA_PROFILE_NAME
-                ],
+                '--extension-name=%s%s' % (
+                    self.environment[constants.LDAPEnv.AAA_PROFILE_NAME],
+                    '' if self.environment[
+                        constants.LDAPEnv.AAA_USE_VM_SSO
+                    ] else '-authz'
+                ),
                 '--entity=%s' % entity,
                 '--entity-name=%s' % name,
             ) +
@@ -242,6 +258,7 @@ class Plugin(plugin.PluginBase):
                     )
                 )
             )
+        return rc == 0
 
     def __init__(self, context):
         super(Plugin, self).__init__(context=context)
@@ -266,17 +283,22 @@ class Plugin(plugin.PluginBase):
         try:
             self.dialog.note(
                 (
+                    ' ',
                     _('NOTE:'),
                     _(
                         'It is highly recommended to test drive the '
                         'configuration before applying it into engine.'
                     ),
                     _(
-                        'Perform at least one Login sequence and one Search '
-                        'sequence.'
+                        'Login sequence is executed automatically, '
+                        'but it is recommended to also execute Search '
+                        'sequence manually after successful Login sequence.'
                     ),
+                    ' ',
                 )
             )
+            # By default force user to test login:
+            sequenceResult = self.sequenceLogin(extensionsDir)
             while True:
                 sequence = self.dialog.queryString(
                     name='OVAAALDAP_LDAP_TOOL_SEQUENCE',
@@ -292,16 +314,16 @@ class Plugin(plugin.PluginBase):
                         _('Login'),
                         _('Search'),
                     ),
-                    default=_('Abort'),
+                    default=_('Done' if sequenceResult else 'Abort'),
                 )
                 if sequence == _('Done').lower():
                     break
                 elif sequence == _('Abort').lower():
                     raise RuntimeError(_('Aborted by user'))
                 elif sequence == _('Login').lower():
-                    self.sequenceLogin(extensionsDir)
+                    sequenceResult = self.sequenceLogin(extensionsDir)
                 elif sequence == _('Search').lower():
-                    self.sequenceSearch(extensionsDir)
+                    sequenceResult = self.sequenceSearch(extensionsDir)
         finally:
             if extensionsDir is not None and os.path.exists(extensionsDir):
                 shutil.rmtree(extensionsDir)
